==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/user/messages/ro/account.php <==
<?php

return [
    '<strong>User</strong> settings' => 'Utilizator',
    '<strong>Your</strong> profile' => 'Profil',
    'All your personal data will be irrevocably deleted.' => 'Toate datele dvs. personale vor fi șterse irevocabil.',
    'Are you sure that you want to delete your account?' => 'Sunteți sigur că doriți să ștergeți contul?',
    'Confirm' => 'Confirmă',
    'Delete account' => 'Sterge acount',
    'E-Mail' => 'E-Mail',
    'Enter your password to continue' => 'Password',
    'Language' => 'Limbă',
    'Modules' => 'App',
    'Not registered users' => 'Nu sunt utilizatori înregistrați',
    'Notifications' => 'Notificari',
    'Other users' => 'Alti utilizatori',
    'Profile' => 'Profil',
    'Save' => 'Salvează',
    'Settings' => 'Impostatii',
    'Users' => 'Utilizatori',
    'You are currently the owner of following spaces:' => 'În prezent, sunteți proprietarul următoarelor spații:',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Trebuie să transferați proprietatea sau să ștergeți aceste spații înainte de a vă putea șterge contul.',
    'Your account cannot be deleted!' => 'Contul dvs. nu poate fi șters!',
    'Your friends' => 'Prietenii tai',
    '<strong>Account</strong> settings' => '',
    '<strong>Confirm</strong></strong> your new email address' => '',
    '<strong>Permissions</strong>' => '',
    '<strong>User</strong> modules' => '',
    'Are you really sure? *ALL* module data for your profile will be deleted!' => '',
    'Blocked users' => '',
    'Changing the username can make some links unusable, for example old links to the profile.' => '',
    'Configure' => '',
    'Current password' => '',
    'Disable' => '',
    'Do you really want to delete your icon image?' => '',
    'Do you really want to delete your logo image?' => '',
    'E-Mail change' => '',
    'Enable' => '',
    'Enhance your profile with modules.' => '',
    'Hello' => '',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => '',
    'Hide introduction tour panel on dashboard' => '',
    'Invalid link! Please make sure that you entered the entire url.' => '',
    'New E-Mail address' => '',
    'New User name' => '',
    'Password Recovery' => '',
    'Permissions' => '',
    'Profile visibility' => '',
    'Registered users only' => '',
    'Save profile' => '',
    'Tags' => '',
    'The entered e-mail address is already in use by another user.' => '',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => '',
    'TimeZone' => '',
    'Username has been changed' => '',
    'Visible for all (also unregistered users)' => '',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => '',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => '',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => '',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => '',
    'Your current password can be changed here.' => '',
    'Your current username is <b>{username}</b>. You can change your current username here.' => '',
    'Your e-mail address has been successfully changed to {email}.' => '',
    'Your password has been successfully changed!' => '',
    'Your username has been changed' => '',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => '',
    '{attribute} "{value}" was not found!' => '',
];

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/user/messages/ro/account.php <==
<?php

return [
    '<strong>Your</strong> profile' => 'Profil',
    'All your personal data will be irrevocably deleted.' => 'Toate datele dvs. personale vor fi șterse irevocabil.',
    'Are you sure that you want to delete your account?' => 'Sunteți sigur că doriți să ștergeți contul?',
    'Confirm' => 'Confirmă',
    'Delete account' => 'Sterge acount',
    'E-Mail' => 'E-Mail',
    'Enter your password to continue' => 'Password',
    'Language' => 'Limbă',
    'Modules' => 'App',
    'Not registered users' => 'Nu sunt utilizatori înregistrați',
    'Notifications' => 'Notificari',
    'Other users' => 'Alti utilizatori',
    'Profile' => 'Profil',
    'Save' => 'Salvează',
    'Users' => 'Utilizatori',
    'You are currently the owner of following spaces:' => 'În prezent, sunteți proprietarul următoarelor spații:',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Trebuie să transferați proprietatea sau să ștergeți aceste spații înainte de a vă putea șterge contul.',
    'Your account cannot be deleted!' => 'Contul dvs. nu poate fi șters!',
    'Your friends' => 'Prietenii tai',
    '<strong>Account</strong> Settings' => '',
    '<strong>Confirm</strong></strong> your new email address' => '',
    '<strong>Permissions</strong>' => '',
    '<strong>User</strong> Account' => '',
    'Account Settings' => '',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => '',
    'Blocked users' => '',
    'Changing the username can make some links unusable, for example old links to the profile.' => '',
    'Current password' => '',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => '',
    'Do you really want to delete your icon image?' => '',
    'Do you really want to delete your logo image?' => '',
    'E-Mail change' => '',
    'Hello' => '',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => '',
    'Hide introduction tour panel on dashboard' => '',
    'Invalid link! Please make sure that you entered the entire url.' => '',
    'New E-Mail address' => '',
    'New User name' => '',
    'Password Recovery' => '',
    'Permissions' => '',
    'Profile Tags' => '',
    'Profile visibility' => '',
    'Registered users only' => '',
    'Save profile' => '',
    'The entered e-mail address is already in use by another user.' => '',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => '',
    'TimeZone' => '',
    'Username has been changed' => '',
    'Visible for all (also unregistered users)' => '',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => '',
    'You cannot use this username.' => '',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => '',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => '',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => '',
    'Your current password can be changed here.' => '',
    'Your current username is <b>{username}</b>. You can change your current username here.' => '',
    'Your e-mail address has been successfully changed to {email}.' => '',
    'Your password has been successfully changed!' => '',
    'Your username has been changed' => '',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => '',
    '{attribute} "{value}" was not found!' => '',
];
